@@ -34,7 +34,7 @@ from vectorio import Circle
 from ulab import numpy as np
 
 
-__version__ = "0.8.1"
+__version__ = "0.8.2"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 
@@ -351,6 +351,7 @@ class Uplot(displayio.Group):
 
     def tick_params(
         self,
+        show_ticks=True,
         tickx_height: int = 8,
         ticky_height: int = 8,
         tickcolor: int = 0xFFFFFF,
@@ -370,7 +371,7 @@ class Uplot(displayio.Group):
 
         """
 
-        self._showticks = True
+        self._showticks = show_ticks
         self._tickheightx = tickx_height
         self._tickheighty = ticky_height
         self._plot_palette[2] = tickcolor
